****************************************
****Final commands for replication******
****************************************

**********************************
*Table 2 - Descriptive statistics*
**********************************

use "main_data.dta", clear 
gen phi_hospall = phi_hosponly+phi_combine
gen phi_ancall = phi_anconly+phi_combine
local controls age1 age2 age3 age4 sex university couple employed /*
*/ phi_hospall phi_ancall inc_less60 inc_less60to125 inc_125plus inc_miss d_visit /*
*/o_visit p_visit n_visit m_visit h_visit 
sum `controls'
sum `controls' if condition==1 //Treatment 1
sum `controls' if condition==2 //Treatment 2

******************************************
*Table 3 - Health insurance comprehension*
******************************************

use "main_data.dta", clear 
sum phi_litQ1 phi_litQ2 phi_litQ3 phi_litALL
sum phi_litQ1 phi_litQ2 phi_litQ3 phi_litALL if no_phi==0 //means for the subset with private health insurance
sum phi_litQ1 phi_litQ2 phi_litQ3 phi_litALL if university==1 //means for the subset with a university education

***************************************************************************
*Table 4 and Figure 2 (Multinomial logit and latent class logit estimates)*
***************************************************************************

/*NOTE: You will need to install user written commands wtp, lclogit, fmlogit & gllamm.   

1. Multinomial logit coefficients and willingness to pay estimates
(These populate the first panel of Figure 2) */

use "T1_data.dta", clear 
clogit choice price anc_copay dental optical P2 P3 naturo massage, cl(id) group(group)
quietly wtp price anc_copay dental optical P2 P3 naturo massage 
matrix wtp2 = r(wtp)*12
matrix list wtp2

use "T2_data.dta", clear 
clogit choice price IN2 IN3 hosp_serv excess anc_copay dental optical P2 P3 naturo massage, cl(id) group(group)
quietly wtp price IN2 IN3 hosp_serv excess anc_copay dental optical P2 P3 naturo massage
matrix wtp2 = r(wtp)*12
matrix list wtp2

*2. Latent class logit coefficients and WTP estimates

*Start with Treatment 1 sample

version 13 /*This is needed to replicate the results in the paper if you are using Stata 14. (There was a change in 
the random number generator between Stata 13 and 14) */

use "T1_data.dta", clear 
local cont age sex university no_phi excell vgood good fair ltime phi_litALL

lclogit choice price anc_copay dental optical P2 P3 naturo massage, group(group) id(id) nclasses(3) membership(`cont') seed(123456789)
display e(bic) //Baysian information criterion
lclogitml

/*The following lines are to calculate the demand elasticity mentioned in Section 6.2 
(see also footnote 29). */
lclogitpr pr, pr
lclogitpr cp, cp
gen N_T1 = ((cp1*pr1)/pr)*((price*[choice1]_b[price])*(1-pr1))+ ((cp2*pr2)/pr)*((price*[choice2]_b[price])*(1-pr2))+ ((cp3*pr3)/pr)*((price*[choice3]_b[price])*(1-pr3))
sum N_T1 

*Now move to WTP

foreach x in `cont' {
qui sum `x'
scalar avg_`x'=r(mean)
}

local exp1 exp([share1]_b[age]*avg_age+[share1]_b[sex]*avg_sex+[share1]_b[university]*avg_university+[share1]_b[no_phi]*avg_no_phi+[share1]_b[excell]*avg_excell+[share1]_b[vgood]*avg_vgood+[share1]_b[good]*avg_good+[share1]_b[fair]*avg_fair+[share1]_b[ltime]*avg_ltime+[share1]_b[phi_litALL]*avg_phi_litALL+[share1]_b[_cons])
local exp2 exp([share2]_b[age]*avg_age+[share2]_b[sex]*avg_sex+[share2]_b[university]*avg_university+[share2]_b[no_phi]*avg_no_phi+[share2]_b[excell]*avg_excell+[share2]_b[vgood]*avg_vgood+[share2]_b[good]*avg_good+[share2]_b[fair]*avg_fair+[share2]_b[ltime]*avg_ltime+[share2]_b[phi_litALL]*avg_phi_litALL+[share2]_b[_cons])

*WTP at means
foreach x in anc_copay dental optical P2 P3 naturo massage {
nlcom (wtp_`x': -12*([choice1]_b[`x']*(`exp1'/(1+`exp1'+`exp2'))+[choice2]_b[`x']*(`exp2'/(1+`exp1'+`exp2'))+[choice3]_b[`x']*(exp(0)/(1+`exp1'+`exp2')))/([choice1]_b[price]*(`exp1'/(1+`exp1'+`exp2'))+[choice2]_b[price]*(`exp2'/(1+`exp1'+`exp2'))+[choice3]_b[price]*(exp(0)/(1+`exp1'+`exp2'))))
}

*WTP response time is 75th percentile & answered all PHI comprehension questions correctly ("Thoughtful respondents" - panel 3 of Figure 2)

qui sum ltime, detail
scalar high_ltime = r(p75)

local exp1 exp([share1]_b[age]*avg_age+[share1]_b[sex]*avg_sex+[share1]_b[university]*avg_university+[share1]_b[no_phi]*avg_no_phi+[share1]_b[excell]*avg_excell+[share1]_b[vgood]*avg_vgood+[share1]_b[good]*avg_good+[share1]_b[fair]*avg_fair+[share1]_b[ltime]*high_ltime+[share1]_b[phi_litALL]*1+[share1]_b[_cons])
local exp2 exp([share2]_b[age]*avg_age+[share2]_b[sex]*avg_sex+[share2]_b[university]*avg_university+[share2]_b[no_phi]*avg_no_phi+[share2]_b[excell]*avg_excell+[share2]_b[vgood]*avg_vgood+[share2]_b[good]*avg_good+[share2]_b[fair]*avg_fair+[share2]_b[ltime]*high_ltime+[share2]_b[phi_litALL]*1+[share2]_b[_cons])

foreach x in anc_copay dental optical P2 P3 naturo massage {
nlcom (wtp_`x': -12*([choice1]_b[`x']*(`exp1'/(1+`exp1'+`exp2'))+[choice2]_b[`x']*(`exp2'/(1+`exp1'+`exp2'))+[choice3]_b[`x']*(exp(0)/(1+`exp1'+`exp2')))/([choice1]_b[price]*(`exp1'/(1+`exp1'+`exp2'))+[choice2]_b[price]*(`exp2'/(1+`exp1'+`exp2'))+[choice3]_b[price]*(exp(0)/(1+`exp1'+`exp2'))))
}

*Now do the same for Treatment 2 sample

version 13

use "T2_data.dta", clear //insert directory for data file `T2_data'. This is the choice data for treatment 12sample
local cont age sex university no_phi excell vgood good fair ltime phi_litALL

lclogit choice price IN2 IN3 hosp_serv excess anc_copay dental optical P2 P3 naturo massage, group(group) id(id) nclasses(3) membership(`cont')
display e(bic) 
lclogitml

/*The following lines are to calculate the demand elasticity mentioned in Section 6.2 
(see also footnote 29). */
lclogitpr pr, pr
lclogitpr cp, cp
gen N_T1 = ((cp1*pr1)/pr)*((price*[choice1]_b[price])*(1-pr1))+ ((cp2*pr2)/pr)*((price*[choice2]_b[price])*(1-pr2))+ ((cp3*pr3)/pr)*((price*[choice3]_b[price])*(1-pr3))
sum N_T1

*Now move to WTP

local cont age sex university no_phi excell vgood good fair ltime phi_litALL
foreach x in `cont' {
qui sum `x'
scalar avg_`x'=r(mean)
}

local exp1 exp([share1]_b[age]*avg_age+[share1]_b[sex]*avg_sex+[share1]_b[university]*avg_university+[share1]_b[no_phi]*avg_no_phi+[share1]_b[excell]*avg_excell+[share1]_b[vgood]*avg_vgood+[share1]_b[good]*avg_good+[share1]_b[fair]*avg_fair+[share1]_b[ltime]*avg_ltime+[share1]_b[phi_litALL]*avg_phi_litALL+[share1]_b[_cons])
local exp2 exp([share2]_b[age]*avg_age+[share2]_b[sex]*avg_sex+[share2]_b[university]*avg_university+[share2]_b[no_phi]*avg_no_phi+[share2]_b[excell]*avg_excell+[share2]_b[vgood]*avg_vgood+[share2]_b[good]*avg_good+[share2]_b[fair]*avg_fair+[share2]_b[ltime]*avg_ltime+[share2]_b[phi_litALL]*avg_phi_litALL+[share2]_b[_cons])

*WTP at means
foreach x in IN2 IN3 hosp_serv excess anc_copay dental optical P2 P3 naturo massage {
nlcom (wtp_`x': -12*([choice1]_b[`x']*(`exp1'/(1+`exp1'+`exp2'))+[choice2]_b[`x']*(`exp2'/(1+`exp1'+`exp2'))+[choice3]_b[`x']*(exp(0)/(1+`exp1'+`exp2')))/([choice1]_b[price]*(`exp1'/(1+`exp1'+`exp2'))+[choice2]_b[price]*(`exp2'/(1+`exp1'+`exp2'))+[choice3]_b[price]*(exp(0)/(1+`exp1'+`exp2'))))
}

**WTP response time is 75th percentile & answered all PHI comprehension questions correctly ("Thoughtful respondents" - panel 3 & 4 of Figure 2)

qui sum ltime, detail
scalar high_ltime = r(p75)

local exp1 exp([share1]_b[age]*avg_age+[share1]_b[sex]*avg_sex+[share1]_b[university]*avg_university+[share1]_b[no_phi]*avg_no_phi+[share1]_b[excell]*avg_excell+[share1]_b[vgood]*avg_vgood+[share1]_b[good]*avg_good+[share1]_b[fair]*avg_fair+[share1]_b[ltime]*high_ltime+[share1]_b[phi_litALL]*1+[share1]_b[_cons])
local exp2 exp([share2]_b[age]*avg_age+[share2]_b[sex]*avg_sex+[share2]_b[university]*avg_university+[share2]_b[no_phi]*avg_no_phi+[share2]_b[excell]*avg_excell+[share2]_b[vgood]*avg_vgood+[share2]_b[good]*avg_good+[share2]_b[fair]*avg_fair+[share2]_b[ltime]*high_ltime+[share2]_b[phi_litALL]*1+[share2]_b[_cons])

foreach x in IN2 IN3 hosp_serv excess anc_copay dental optical P2 P3 naturo massage {
nlcom (wtp_`x': -12*([choice1]_b[`x']*(`exp1'/(1+`exp1'+`exp2'))+[choice2]_b[`x']*(`exp2'/(1+`exp1'+`exp2'))+[choice3]_b[`x']*(exp(0)/(1+`exp1'+`exp2')))/([choice1]_b[price]*(`exp1'/(1+`exp1'+`exp2'))+[choice2]_b[price]*(`exp2'/(1+`exp1'+`exp2'))+[choice3]_b[price]*(exp(0)/(1+`exp1'+`exp2'))))
}

************************************************
*Table 5 - Random parameters latent class logit*
************************************************

/*You will need to have the user written command `gmnl' installed to get standard errors.
This part uses the supplied .ado file `lclogitmod', which is a modified version of lclogit. The 
main modification is to use the `mixlogit' command in place of `clogit' for each iteration of
the EM algorithm. Note this model can take several hours to estimate. */

*Start with Treatment 1 sample

use "T1_data.dta", clear 
version 13
local cont age sex university no_phi excell vgood good fair ltime phi_litALL

set seed 123456789
lclogitmod choice price anc_copay dental optical P2 P3 naturo massage, group(group) id(id) nclasses(3) membership(`cont') nrep(500) burn(37)
display e(bic) //Baysian information criterion

/*Obtaining standard errors after EM estimation is difficult. Train (2008) suggests using the outer 
product gradient, which I follow. To achieve this I pass over class level estimates from the RPLCL model to 
the user written command `gmnl', which is used to estimate the generalized multinomial logit model as well 
as normal-mixed logit models. (I thank Hong Ill Yoo for suggesting this approach. Any mistakes are my 
own.)
*/

lclogitpr cp, cp
matrix A = e(B)
matrix B1 = A[1,1..16]
matrix B2 = A[2,1..16]
matrix B3 = A[3,1..16]

gmnl choice [iw=cp1], rand(price anc_copay dental optical P2 P3 naturo massage) iter(0) id(id) group(group) from(B1, copy) mixl vce(opg)
estimates save rplcl_t1_c1, replace
gmnl choice [iw=cp2], rand(price anc_copay dental optical P2 P3 naturo massage) iter(0) id(id) group(group) from(B2, copy) mixl vce(opg)
estimates save rplcl_t1_c2, replace
gmnl choice [iw=cp3], rand(price anc_copay dental optical P2 P3 naturo massage) iter(0) id(id) group(group) from(B3, copy) mixl vce(opg)
estimates save rplcl_t1_c3, replace

*Now do Treatment 2 sample

use "T2_data.dta", clear 
version 13

local cont age sex university no_phi excell vgood good fair ltime phi_litALL

lclogitmod choice price IN2 IN3 hosp_serv excess anc_copay dental optical P2 P3 naturo massage, group(group) id(id) nclasses(3) membership(`cont') nrep(500) burn(37)
display e(bic)

lclogitpr cp, cp
matrix A = e(B)
matrix B1 = A[1,1..24]
matrix B2 = A[2,1..24]
matrix B3 = A[3,1..24]

gmnl choice [iw=cp1], rand(price IN2 IN3 hosp_serv excess anc_copay dental optical P2 P3 naturo massage) iter(0) id(id) group(group) from(B1, copy) mixl vce(opg)
estimates save rplcl_t2_c3, replace //note, set as class 3 to match tables in paper
gmnl choice [iw=cp2], rand(price IN2 IN3 hosp_serv excess anc_copay dental optical P2 P3 naturo massage) iter(0) id(id) group(group) from(B2, copy) mixl vce(opg)
estimates save rplcl_t2_c2, replace
gmnl choice [iw=cp3], rand(price IN2 IN3 hosp_serv excess anc_copay dental optical P2 P3 naturo massage) iter(0) id(id) group(group) from(B3, copy) mixl vce(opg)
estimates save rplcl_t2_c1, replace //note, set as class 1 to match tables in paper

**************************************************************
*Table 6 - Proportions of respondents with WTP > benefits cap*
**************************************************************

/*Beause of the significant computational time in estimating lclogitmod, I stored the RPLCL estimates 
and draw on the stored results in the simulation programs below.

I'll use the example of irrational WTP for dental to explain the code to follow.

The line "gen double b_dental_c1 = rnormal([Mean]_b[dental],abs([SD]_b[dental]))" creates a variable `b_dental_c1', 
which is a simulated vector of coefficients for the dental attribute (dental coverage = $750) for 
the class 1 group in the random parameters latent class logit model. From the RPLCL model, you can 
confirm that the beta parameter is 1.0379905 and the estimated standard deviation is 0.44924836 
(see also Table 6).

The line "gen wtp_dental_c1 = -12*(b_dental_c1/b_price_c1)" (contained within a loop) creates a 
variable called `wtp_dental_c1', which is the simulated WTP for class 1 respondents. Note this is 
the ratio of two normal random variables so its mean is undefined but percentiles (e.g. median, 
thresholds for irrational WTP) are meaningful. The figure is multiplied by 12 to get an annual amount.

The lines "gen irrat_dental_c1 = 0" and 
"replace irrat_dental_c1 = 1 if (b_dental_c1>0&b_price_c1>0)|(wtp_dental_c1>350&b_dental_c1>0)" 
(contained within a loop) create `irrat_dental_c1', which is the simulated number of people with WTP 
above the rational threshold in class 1. In the case of dental coverage, this is the simulated 
proportion of people who would be willing to pay >$350 to increase the cap on dental coverage from 
$350 to $700.

The final step is to weight the class specific WTP vectors by the class shares as estimated by the 
RPLCL model. The command display .3571717*C1+.3607088*C2+.2821195*C3 achieves this. The variables
C1, C2 and C3 are the proportions of people with irrational WTP in class 1, 2 and 3 respectively. The
other values are the estimated class shares. In Treatment 1 for example, the share for class 1 is 
.3571717, for class 2 is .3607088 and for class 3 is .2821195.    
*/ 

*Start with Treatment 1 RPLCL estimates

clear all
version 13
set seed 123456789

set obs 10000 //this sets the number of simulations
*Class 1
est use rplcl_t1_c1 //open RPLCL treatment 1 class 1 estimates 
gen double b_dental_c1 = rnormal([Mean]_b[dental],abs([SD]_b[dental]))
gen double b_optical_c1 = rnormal([Mean]_b[optical],abs([SD]_b[optical]))
gen double b_P2_c1 = rnormal([Mean]_b[P2],abs([SD]_b[P2]))
gen double b_P3_c1 = rnormal([Mean]_b[P3],abs([SD]_b[P3]))
gen double b_naturo_c1 = rnormal([Mean]_b[naturo],abs([SD]_b[naturo]))
gen double b_massage_c1 = rnormal([Mean]_b[massage],abs([SD]_b[massage]))   
gen double b_price_c1 = rnormal([Mean]_b[price],abs([SD]_b[price]))  

*Class 2
est use rplcl_t1_c2 //open RPLCL treatment 1 class 2 estimates 
gen double b_dental_c2 = rnormal([Mean]_b[dental],abs([SD]_b[dental]))
gen double b_optical_c2 = rnormal([Mean]_b[optical],abs([SD]_b[optical]))
gen double b_P2_c2 = rnormal([Mean]_b[P2],abs([SD]_b[P2]))
gen double b_P3_c2 = rnormal([Mean]_b[P3],abs([SD]_b[P3]))
gen double b_naturo_c2 = rnormal([Mean]_b[naturo],abs([SD]_b[naturo]))
gen double b_massage_c2 = rnormal([Mean]_b[massage],abs([SD]_b[massage]))   
gen double b_price_c2 = rnormal([Mean]_b[price],abs([SD]_b[price]))  

*Class 3
est use rplcl_t1_c3 //open RPLCL treatment 1 class 3 estimates 
gen double b_dental_c3 = rnormal([Mean]_b[dental],abs([SD]_b[dental]))
gen double b_optical_c3 = rnormal([Mean]_b[optical],abs([SD]_b[optical]))
gen double b_P2_c3 = rnormal([Mean]_b[P2],abs([SD]_b[P2]))
gen double b_P3_c3 = rnormal([Mean]_b[P3],abs([SD]_b[P3]))
gen double b_naturo_c3 = rnormal([Mean]_b[naturo],abs([SD]_b[naturo]))
gen double b_massage_c3 = rnormal([Mean]_b[massage],abs([SD]_b[massage]))   
gen double b_price_c3 = rnormal([Mean]_b[price],abs([SD]_b[price]))   

foreach x in 1 2 3 {
gen wtp_dental_c`x' = -12*(b_dental_c`x'/b_price_c`x')
gen irrat_dental_c`x' = 0
replace irrat_dental_c`x' = 1 if (b_dental_c`x'>0&b_price_c`x'>0)|(wtp_dental_c`x'>350&b_dental_c`x'>0)

gen wtp_optical_c`x' = -12*(b_optical_c`x'/b_price_c`x')
gen irrat_optical_c`x' = 0
replace irrat_optical_c`x' = 1 if (b_optical_c`x'>0&b_price_c`x'>0)|(wtp_optical_c`x'>150&b_optical_c`x'>0)

gen wtp_P2_c`x' = -12*(b_P2_c`x'/b_price_c`x')
gen irrat_P2_c`x' = 0
replace irrat_P2_c`x' = 1 if (b_P2_c`x'>0&b_price_c`x'>0)|(wtp_P2_c`x'>150&b_P2_c`x'>0)

gen wtp_P3_c`x' = -12*(b_P3_c`x'/b_price_c`x')
gen irrat_P3_c`x' = 0
replace irrat_P3_c`x' = 1 if (b_P3_c`x'>0&b_price_c`x'>0)|(wtp_P3_c`x'>300&b_P3_c`x'>0)

gen wtp_naturo_c`x' = -12*(b_naturo_c`x'/b_price_c`x')
gen irrat_naturo_c`x' = 0
replace irrat_naturo_c`x' = 1 if (b_naturo_c`x'>0&b_price_c`x'>0)|(wtp_naturo_c`x'>100&b_naturo_c`x'>0)

gen wtp_massage_c`x' = -12*(b_massage_c`x'/b_price_c`x')
gen irrat_massage_c`x' = 0
replace irrat_massage_c`x' = 1 if (b_massage_c`x'>0&b_price_c`x'>0)|(wtp_massage_c`x'>100&b_massage_c`x'>0)
}

*Column 4 of Table 6

foreach z in dental optical P2 P3 naturo massage {
foreach x in 1 2 3 {
qui sum irrat_`z'_c`x'
scalar C`x' = r(mean)
} 
*Irrational WTP `z' - all classes
display .3571717*C1+.3607088*C2+.2821195*C3
}

*Column 2 of Table 6

foreach z in dental optical P2 P3 naturo massage {
foreach x in 1 2 3 {
qui sum irrat_`z'_c`x'
scalar C`x' = r(mean)
} 
*Irrational WTP `z' - all classes
display (.3571717*C1+.3607088*C2)/(.3571717+.3607088)
}

*Now do Treatment 2 RPLCL estimates

clear all

version 13
set seed 123456789

set obs 10000
*Class 1
est use rplcl_t2_c1 //open RPLCL treatment 2 class 1 estimates 
gen double b_dental_c1 = rnormal([Mean]_b[dental],abs([SD]_b[dental]))
gen double b_optical_c1 = rnormal([Mean]_b[optical],abs([SD]_b[optical]))
gen double b_P2_c1 = rnormal([Mean]_b[P2],abs([SD]_b[P2]))
gen double b_P3_c1 = rnormal([Mean]_b[P3],abs([SD]_b[P3]))
gen double b_naturo_c1 = rnormal([Mean]_b[naturo],abs([SD]_b[naturo]))
gen double b_massage_c1 = rnormal([Mean]_b[massage],abs([SD]_b[massage]))   
gen double b_price_c1 = rnormal([Mean]_b[price],abs([SD]_b[price]))  
gen double b_excess_c1 = rnormal([Mean]_b[excess],abs([SD]_b[excess])) 

*Class 2
est use rplcl_t2_c2 //open RPLCL treatment 2 class 2 estimates 
gen double b_dental_c2 = rnormal([Mean]_b[dental],abs([SD]_b[dental]))
gen double b_optical_c2 = rnormal([Mean]_b[optical],abs([SD]_b[optical]))
gen double b_P2_c2 = rnormal([Mean]_b[P2],abs([SD]_b[P2]))
gen double b_P3_c2 = rnormal([Mean]_b[P3],abs([SD]_b[P3]))
gen double b_naturo_c2 = rnormal([Mean]_b[naturo],abs([SD]_b[naturo]))
gen double b_massage_c2 = rnormal([Mean]_b[massage],abs([SD]_b[massage]))   
gen double b_price_c2 = rnormal([Mean]_b[price],abs([SD]_b[price]))  
gen double b_excess_c2 = rnormal([Mean]_b[excess],abs([SD]_b[excess]))  


*Class 3
est use rplcl_t2_c3 //open RPLCL treatment 2 class 3 estimates 
gen double b_dental_c3 = rnormal([Mean]_b[dental],abs([SD]_b[dental]))
gen double b_optical_c3 = rnormal([Mean]_b[optical],abs([SD]_b[optical]))
gen double b_P2_c3 = rnormal([Mean]_b[P2],abs([SD]_b[P2]))
gen double b_P3_c3 = rnormal([Mean]_b[P3],abs([SD]_b[P3]))
gen double b_naturo_c3 = rnormal([Mean]_b[naturo],abs([SD]_b[naturo]))
gen double b_massage_c3 = rnormal([Mean]_b[massage],abs([SD]_b[massage]))   
gen double b_price_c3 = rnormal([Mean]_b[price],abs([SD]_b[price]))  
gen double b_excess_c3 = rnormal([Mean]_b[excess],abs([SD]_b[excess])) 


foreach x in 1 2 3 {
gen wtp_dental_c`x' = -12*(b_dental_c`x'/b_price_c`x')
gen irrat_dental_c`x' = 0
replace irrat_dental_c`x' = 1 if (b_dental_c`x'>0&b_price_c`x'>0)|(wtp_dental_c`x'>350&b_dental_c`x'>0)

gen wtp_optical_c`x' = -12*(b_optical_c`x'/b_price_c`x')
gen irrat_optical_c`x' = 0
replace irrat_optical_c`x' = 1 if (b_optical_c`x'>0&b_price_c`x'>0)|(wtp_optical_c`x'>150&b_optical_c`x'>0)

gen wtp_P2_c`x' = -12*(b_P2_c`x'/b_price_c`x')
gen irrat_P2_c`x' = 0
replace irrat_P2_c`x' = 1 if (b_P2_c`x'>0&b_price_c`x'>0)|(wtp_P2_c`x'>150&b_P2_c`x'>0)

gen wtp_P3_c`x' = -12*(b_P3_c`x'/b_price_c`x')
gen irrat_P3_c`x' = 0
replace irrat_P3_c`x' = 1 if (b_P3_c`x'>0&b_price_c`x'>0)|(wtp_P3_c`x'>300&b_P3_c`x'>0)

gen wtp_naturo_c`x' = -12*(b_naturo_c`x'/b_price_c`x')
gen irrat_naturo_c`x' = 0
replace irrat_naturo_c`x' = 1 if (b_naturo_c`x'>0&b_price_c`x'>0)|(wtp_naturo_c`x'>100&b_naturo_c`x'>0)

gen wtp_massage_c`x' = -12*(b_massage_c`x'/b_price_c`x')
gen irrat_massage_c`x' = 0
replace irrat_massage_c`x' = 1 if (b_massage_c`x'>0&b_price_c`x'>0)|(wtp_massage_c`x'>100&b_massage_c`x'>0)

gen wtp_excess_c`x' = -12*(b_excess_c`x'/b_price_c`x')
gen irrat_excess_c`x' = 0
replace irrat_excess_c`x' = 1 if (b_excess_c`x'>0&b_price_c`x'>0)|(wtp_excess_c`x'>250&b_excess_c`x'>0)
}

*Column 5 of Table 6

foreach z in dental optical P2 P3 naturo massage excess {
foreach x in 1 2 3 {
qui sum irrat_`z'_c`x'
scalar C`x' = r(mean)
} 
*Irrational WTP `z' - all classes
display 0.487*C1+0.305*C2+0.208*C3
}

*Column 3 of Table 6

foreach z in dental optical P2 P3 naturo massage excess {
foreach x in 1 2 3 {
qui sum irrat_`z'_c`x'
scalar C`x' = r(mean)
} 
*Irrational WTP `z' - all classes
display (0.487*C1+0.305*C2)/(0.487+0.305)
}

**************************************************
*Table 7 & Table C1 - Policy choice probabilities*
**************************************************

run simulation_tables.do /*this do file re-estimates the LCL models and outputs the choice simulation
tables as matrices. */

**************************************************************
*Table 8 & Table 9 - Attribute maximisation choice strategies*
**************************************************************

*Start with Treatment 1 sample

use "T1_data.dta", clear 

foreach x in lowest_price high_copay high_dental high_optical high_physical high_naturo high_massage {
gen X_`x' = choice*`x'
egen Y_`x' = sum(X_`x'), by(id)
egen Z_`x' = sum(`x'), by(id)
gen `x'_strat = 0
replace `x'_strat  = 1 if Z_`x'==Y_`x'
}
drop X_* Y_* Z_*
gen strat_all = lowest_price_strat+high_copay_strat+high_dental_strat+high_optical_strat+high_physical_strat+high_naturo_strat+high_massage_strat 
replace strat_all = 1 if strat_all>0

*The next line populates column 2 of Table 7
mean lowest_price_strat high_copay_strat high_dental_strat high_optical_strat high_physical_strat high_naturo_strat high_massage_strat strat_all

keep if _j==1
local visits dentist_visits o_visit physical_visits naturo_visits massage_visits 

*The next set of commands are the regression results to populate row 2 of Table 8.
eststo: qui reg lowest_price_strat sex age inc_less60to125 inc_125plus inc_miss city sa_riskav university couple excell vgood good fair no_phi phi_litALL `visits', robust
eststo: qui reg high_dental_strat  sex age inc_less60to125 inc_125plus inc_miss city sa_riskav university couple excell vgood good fair no_phi phi_litALL `visits', robust
eststo: qui reg high_optical_strat sex age inc_less60to125 inc_125plus inc_miss city sa_riskav university couple excell vgood good fair no_phi phi_litALL `visits', robust
eststo: qui reg high_optical_strat sex age inc_less60to125 inc_125plus inc_miss city sa_riskav university couple excell vgood good fair no_phi phi_litALL `visits' glasses, robust
eststo: qui reg high_physical_strat  sex age inc_less60to125 inc_125plus inc_miss city sa_riskav university couple excell vgood good fair no_phi phi_litALL `visits', robust
eststo: qui reg high_naturo_strat sex age inc_less60to125 inc_125plus inc_miss city sa_riskav university couple excell vgood good fair no_phi phi_litALL `visits', robust
eststo: qui reg high_massage_strat  sex age inc_less60to125 inc_125plus inc_miss city sa_riskav university couple excell vgood good fair no_phi phi_litALL `visits', robust
esttab, se compress b(3) se(3) star(* 0.10 ** 0.05 *** 0.01)
eststo clear

*Now Treatment 2 sample 

use "T2_data.dta", clear 

foreach x in lowest_price high_inclusions low_excess high_hospserv high_copay high_dental high_optical high_physical high_naturo high_massage {
gen X_`x' = choice*`x'
egen Y_`x' = sum(X_`x'), by(id)
egen Z_`x' = sum(`x'), by(id)
gen `x'_strat = 0
replace `x'_strat  = 1 if Z_`x'==Y_`x'
}
drop X_* Y_* Z_*
replace high_massage_strat = 0 if block=="C" //to deal with the fact only two variations
gen strat_all = lowest_price_strat+high_inclusions_strat+low_excess_strat+high_hospserv_strat+high_copay_strat+high_dental_strat+high_optical_strat+high_physical_strat+high_naturo_strat+high_massage_strat 
replace strat_all = 1 if strat_all>0

*The next line populates column 3 of Table 7
mean lowest_price_strat high_inclusions_strat low_excess_strat high_hospserv_strat high_copay_strat high_dental_strat high_optical_strat high_physical_strat high_naturo_strat high_massage_strat strat_all 

keep if _j==1

*The next set of commands are the regression results to populate row 3 of Table 8.
local visits dentist_visits o_visit physical_visits naturo_visits massage_visits h_visit
eststo: qui reg lowest_price_strat sex age inc_less60to125 inc_125plus inc_miss city sa_riskav university couple excell vgood good fair no_phi phi_litALL `visits', robust
eststo: qui reg high_dental_strat  sex age inc_less60to125 inc_125plus inc_miss city sa_riskav university couple excell vgood good fair no_phi phi_litALL `visits', robust 
eststo: qui reg high_optical_strat sex age inc_less60to125 inc_125plus inc_miss city sa_riskav university couple excell vgood good fair no_phi phi_litALL `visits', robust
eststo: qui reg high_optical_strat sex age inc_less60to125 inc_125plus inc_miss city sa_riskav university couple excell vgood good fair no_phi phi_litALL `visits' glasses, robust
eststo: qui reg high_physical_strat  sex age inc_less60to125 inc_125plus inc_miss city sa_riskav university couple excell vgood good fair no_phi phi_litALL `visits', robust
eststo: qui reg high_naturo_strat sex age inc_less60to125 inc_125plus inc_miss city sa_riskav university couple excell vgood good fair no_phi phi_litALL `visits', robust
eststo: qui reg high_massage_strat  sex age inc_less60to125 inc_125plus inc_miss city sa_riskav university couple excell vgood good fair no_phi phi_litALL `visits', robust
esttab, se compress b(3) se(3) star(* 0.10 ** 0.05 *** 0.01)
eststo clear

************************************************
*Table 10 - Attribute non-attendance estimation*
************************************************

//Note you will need to install user command eaalogit

*Start with treatment 1

use "T1_data.dta", clear 

eaalogit choice price anc_copay dental optical P2 P3 naturo massage, /*
*/id(id) group(group) k(2) eaa(x1 x2 x2 x2 x2 x2 x2 x2) zvar(age sex university no_phi ltime phi_litALL) difficult 

quietly wtp price anc_copay dental optical P2 P3 naturo massage 
matrix wtp2 = r(wtp)*12
matrix list wtp2

qui predict g1, xb equation(Gamma1)
qui predict g2, xb equation(Gamma2)

gen prob_price = 1-invlogit(-g1)
gen prob_anc = 1-invlogit(-g2)

sum prob_price prob_anc

*Marginal effects for Table C2

foreach var in sex university no_phi phi_litALL {
tempvar p1_g1 p0_g1 p1_g2 p0_g2
qui g temp_`var' = `var'
qui replace `var' = 0
qui predict `p0_g1', xb equation(Gamma1)
qui predict `p0_g2', xb equation(Gamma2)
qui replace `p0_g1' = 1-invlogit(-`p0_g1')
qui replace `p0_g2' = 1-invlogit(-`p0_g2')
qui replace `var' = 1
qui predict `p1_g1', xb equation(Gamma1)
qui predict `p1_g2', xb equation(Gamma2)
qui replace `p1_g1' = 1-invlogit(-`p1_g1')
qui replace `p1_g2' = 1-invlogit(-`p1_g2')
qui g me_`var'_g1 = `p1_g1'-`p0_g1' 
qui g me_`var'_g2 = `p1_g2'-`p0_g2' 
sum me_`var'*
qui replace `var' = temp_`var'
drop temp_* me_*
}

qui g me_age_g1 = ([Gamma1]age*exp(g1))/(1+exp(g1))^2
qui g me_age_g2 = ([Gamma2]age*exp(g2))/(1+exp(g2))^2
sum me_age* 
drop me_*

qui g me_ltime_g1 = ([Gamma1]ltime*exp(g1))/(1+exp(g1))^2
qui g me_ltime_g2 = ([Gamma2]ltime*exp(g2))/(1+exp(g2))^2
sum me_ltime* 
drop me_*

*Now treatment 2

use "T2_data.dta", clear 

eaalogit choice price IN2 IN3 hosp_serv excess anc_copay dental optical P2 P3 naturo massage, /*
*/id(id) group(group) k(3) eaa(x1 x2 x2 x2 x2 x3 x3 x3 x3 x3 x3 x3) zvar(age sex university no_phi ltime phi_litALL)

quietly wtp price IN2 IN3 hosp_serv excess anc_copay dental optical P2 P3 naturo massage 
matrix wtp2 = r(wtp)*12
matrix list wtp2

qui predict g1, xb equation(Gamma1)
qui predict g2, xb equation(Gamma2)
qui predict g3, xb equation(Gamma3)

gen prob_price = 1-invlogit(-g1)
gen prob_anc = 1-invlogit(-g2)
gen prob_hosp = 1-invlogit(-g3)

sum prob_price prob_anc prob_hosp

*Marginal effects for Table C3

foreach var in sex university no_phi phi_litALL {
tempvar p1_g1 p0_g1 p1_g2 p0_g2 p1_g3 p0_g3
qui g temp_`var' = `var'
qui replace `var' = 0
qui predict `p0_g1', xb equation(Gamma1)
qui predict `p0_g2', xb equation(Gamma2)
qui predict `p0_g3', xb equation(Gamma3)
qui replace `p0_g1' = 1-invlogit(-`p0_g1')
qui replace `p0_g2' = 1-invlogit(-`p0_g2')
qui replace `p0_g3' = 1-invlogit(-`p0_g3')
qui replace `var' = 1
qui predict `p1_g1', xb equation(Gamma1)
qui predict `p1_g2', xb equation(Gamma2)
qui predict `p1_g3', xb equation(Gamma3)
qui replace `p1_g1' = 1-invlogit(-`p1_g1')
qui replace `p1_g2' = 1-invlogit(-`p1_g2')
qui replace `p1_g3' = 1-invlogit(-`p1_g3')
qui g me_`var'_g1 = `p1_g1'-`p0_g1' 
qui g me_`var'_g2 = `p1_g2'-`p0_g2' 
qui g me_`var'_g3 = `p1_g3'-`p0_g3' 
sum me_`var'*
qui replace `var' = temp_`var'
drop temp_* me_*
}

qui g me_age_g1 = ([Gamma1]age*exp(g1))/(1+exp(g1))^2
qui g me_age_g2 = ([Gamma2]age*exp(g2))/(1+exp(g2))^2
qui g me_age_g3 = ([Gamma3]age*exp(g3))/(1+exp(g3))^2
sum me_age* 
drop me_*

qui g me_ltime_g1 = ([Gamma1]ltime*exp(g1))/(1+exp(g1))^2
qui g me_ltime_g2 = ([Gamma2]ltime*exp(g2))/(1+exp(g2))^2
qui g me_ltime_g3 = ([Gamma3]ltime*exp(g3))/(1+exp(g3))^2
sum me_ltime* 
drop me_*

******************************************************
*Dominated choices (results mentioned in section 6.1)*
******************************************************

use "main_data.dta", clear

drop if condition==2&_n<13 /*These are observations where the choice set order was accidentally altered, as 
mentioned in footnote 15. Note that these few observations are not excluded from the descriptive statistics
or the health insurance comprehension results. Arguably I could have ecluded them from the descriptive 
statistics but there are so few it's inconsequential. I saw no reason to exclude them from the PHI
comprehension results since it was only the choice task order that was an issue for these respondents and
their other data (i.e. demographics, PHI comprehension) are all valid. They are not included in the T2_data
file and therefore not included in any of the regression or prediction results. */ 

sum dominated if condition==1 //treatment 1
sum dominated if condition==2 //treatment 2

local cont sex age inc_less60to125 inc_125plus inc_miss city sa_riskav university couple excell vgood /*
*/good fair no_phi phi_litQ1 phi_litQ2 phi_litQ3

logit dominated `cont' i.m_visit if condition==1&block=="A", robust
margins m_visit, post
nlcom _b[1.m_visit] - _b[0.m_visit]
logit dominated `cont' i.n_visit if condition==1&block=="B", robust
margins n_visit, post
nlcom _b[1.n_visit] - _b[0.n_visit]

*************************************************************************************
*Expected benefits to increases in ancillaries caps (figures mention in section 6.5)*
*************************************************************************************

use "main_data.dta", clear

*Note calculations assume a 70% insurer copay

qui gen glasses_ben = glasses_cost2*0.7
qui replace glasses_ben = glasses_ben-150
qui replace glasses_ben = 0 if glasses_ben<0
qui replace glasses_ben = 150 if glasses_ben>150

qui gen dental_ben = dental_cost*0.7
qui replace dental_ben = dental_ben-300
qui replace dental_ben = 0 if dental_ben<0
qui replace dental_ben = 300 if dental_ben>300

qui gen phys2_ben = physical_cost*0.7
qui replace phys2_ben = 150 if phys2_ben>150

qui gen phys3_ben = physical_cost*0.7
qui replace phys3_ben = 300 if phys3_ben>300

qui gen nat_ben = naturo_cost*0.7
qui replace nat_ben = 100 if nat_ben>100

qui gen mass_ben = massage_cost*0.7
qui replace mass_ben = 100 if mass_ben>100

sum glasses_ben dental_ben phys2_ben phys3_ben nat_ben mass_ben

******************************************************
*WTP values for Figure C1 (non-linear price variable)*
******************************************************

*Start with treatment 1

use "T1_data.dta", clear 

version 13

*Log price
gen lprice = log(price)
clogit choice lprice anc_copay dental optical P2 P3 naturo massage, cl(id) group(group)

sum price
scalar mprice = r(mean)
foreach x in anc_copay dental optical P2 P3 naturo massage {
nlcom (wtp_`x': -12*(_b[`x']/_b[lprice])*mprice)
}

local cont age sex university no_phi excell vgood good fair ltime phi_litALL

lclogit choice lprice anc_copay dental optical P2 P3 naturo massage, group(group) id(id) nclasses(3) membership(`cont') seed(123456789)
display e(bic) //Baysian information criterion
lclogitml

foreach x in `cont' {
qui sum `x'
scalar avg_`x'=r(mean)
}

local exp1 exp([share1]_b[age]*avg_age+[share1]_b[sex]*avg_sex+[share1]_b[university]*avg_university+[share1]_b[no_phi]*avg_no_phi+[share1]_b[excell]*avg_excell+[share1]_b[vgood]*avg_vgood+[share1]_b[good]*avg_good+[share1]_b[fair]*avg_fair+[share1]_b[ltime]*avg_ltime+[share1]_b[phi_litALL]*avg_phi_litALL+[share1]_b[_cons])
local exp2 exp([share2]_b[age]*avg_age+[share2]_b[sex]*avg_sex+[share2]_b[university]*avg_university+[share2]_b[no_phi]*avg_no_phi+[share2]_b[excell]*avg_excell+[share2]_b[vgood]*avg_vgood+[share2]_b[good]*avg_good+[share2]_b[fair]*avg_fair+[share2]_b[ltime]*avg_ltime+[share2]_b[phi_litALL]*avg_phi_litALL+[share2]_b[_cons])

*WTP at means
foreach x in anc_copay dental optical P2 P3 naturo massage {
nlcom (wtp_`x': mprice*-12*([choice1]_b[`x']*(`exp1'/(1+`exp1'+`exp2'))+[choice2]_b[`x']*(`exp2'/(1+`exp1'+`exp2'))+[choice3]_b[`x']*(exp(0)/(1+`exp1'+`exp2')))/([choice1]_b[lprice]*(`exp1'/(1+`exp1'+`exp2'))+[choice2]_b[lprice]*(`exp2'/(1+`exp1'+`exp2'))+[choice3]_b[lprice]*(exp(0)/(1+`exp1'+`exp2'))))
}

*Quadratic price
gen price2 = price^2
clogit choice price price2 anc_copay dental optical P2 P3 naturo massage, cl(id) group(group)

foreach x in anc_copay dental optical P2 P3 naturo massage {
nlcom (wtp_`x': -12*(_b[`x']/(_b[price]+2*_b[price2]*mprice)))
} //this loop calculates WTP for MNL

local cont age sex university no_phi excell vgood good fair ltime phi_litALL

lclogit choice price price2 anc_copay dental optical P2 P3 naturo massage, group(group) id(id) nclasses(3) membership(`cont') seed(123456789)
display e(bic) //Baysian information criterion
lclogitml


local exp1 exp([share1]_b[age]*avg_age+[share1]_b[sex]*avg_sex+[share1]_b[university]*avg_university+[share1]_b[no_phi]*avg_no_phi+[share1]_b[excell]*avg_excell+[share1]_b[vgood]*avg_vgood+[share1]_b[good]*avg_good+[share1]_b[fair]*avg_fair+[share1]_b[ltime]*avg_ltime+[share1]_b[phi_litALL]*avg_phi_litALL+[share1]_b[_cons])
local exp2 exp([share2]_b[age]*avg_age+[share2]_b[sex]*avg_sex+[share2]_b[university]*avg_university+[share2]_b[no_phi]*avg_no_phi+[share2]_b[excell]*avg_excell+[share2]_b[vgood]*avg_vgood+[share2]_b[good]*avg_good+[share2]_b[fair]*avg_fair+[share2]_b[ltime]*avg_ltime+[share2]_b[phi_litALL]*avg_phi_litALL+[share2]_b[_cons])

*WTP at means
foreach x in anc_copay dental optical P2 P3 naturo massage {
nlcom (wtp_`x': -12*([choice1]_b[`x']*(`exp1'/(1+`exp1'+`exp2'))+[choice2]_b[`x']*(`exp2'/(1+`exp1'+`exp2'))+[choice3]_b[`x']*(exp(0)/(1+`exp1'+`exp2')))/(([choice1]_b[price]+2*mprice*[choice1]_b[price2])*(`exp1'/(1+`exp1'+`exp2'))+([choice2]_b[price]+2*mprice*[choice2]_b[price2])*(`exp2'/(1+`exp1'+`exp2'))+([choice3]_b[price]+2*mprice*[choice3]_b[price2])*(exp(0)/(1+`exp1'+`exp2'))))
} //this loop caclulates WTP for LCL

*Now treatment 2

use "T2_data.dta", clear

version 13

*Log price

gen lprice = log(price)
clogit choice lprice IN2 IN3 hosp_serv excess anc_copay dental optical P2 P3 naturo massage, cl(id) group(group)

sum price
scalar mprice = r(mean)
foreach x in IN2 IN3 hosp_serv excess anc_copay dental optical P2 P3 naturo massage {
nlcom (wtp_`x': -12*(_b[`x']/_b[lprice])*mprice)
} //this loop calculates WTP for MNL

local cont age sex university no_phi excell vgood good fair ltime phi_litALL

lclogit choice lprice IN2 IN3 hosp_serv excess anc_copay dental optical P2 P3 naturo massage, group(group) id(id) nclasses(3) membership(`cont') seed(123456789)
display e(bic) //Baysian information criterion
lclogitml

foreach x in `cont' {
qui sum `x'
scalar avg_`x'=r(mean)
}

local exp1 exp([share1]_b[age]*avg_age+[share1]_b[sex]*avg_sex+[share1]_b[university]*avg_university+[share1]_b[no_phi]*avg_no_phi+[share1]_b[excell]*avg_excell+[share1]_b[vgood]*avg_vgood+[share1]_b[good]*avg_good+[share1]_b[fair]*avg_fair+[share1]_b[ltime]*avg_ltime+[share1]_b[phi_litALL]*avg_phi_litALL+[share1]_b[_cons])
local exp2 exp([share2]_b[age]*avg_age+[share2]_b[sex]*avg_sex+[share2]_b[university]*avg_university+[share2]_b[no_phi]*avg_no_phi+[share2]_b[excell]*avg_excell+[share2]_b[vgood]*avg_vgood+[share2]_b[good]*avg_good+[share2]_b[fair]*avg_fair+[share2]_b[ltime]*avg_ltime+[share2]_b[phi_litALL]*avg_phi_litALL+[share2]_b[_cons])

*WTP at means
foreach x in IN2 IN3 hosp_serv excess anc_copay dental optical P2 P3 naturo massage {
nlcom (wtp_`x': mprice*-12*([choice1]_b[`x']*(`exp1'/(1+`exp1'+`exp2'))+[choice2]_b[`x']*(`exp2'/(1+`exp1'+`exp2'))+[choice3]_b[`x']*(exp(0)/(1+`exp1'+`exp2')))/([choice1]_b[lprice]*(`exp1'/(1+`exp1'+`exp2'))+[choice2]_b[lprice]*(`exp2'/(1+`exp1'+`exp2'))+[choice3]_b[lprice]*(exp(0)/(1+`exp1'+`exp2'))))
} //this loop calculated WTP for LCL

*Quadratic price

gen price2 = price^2
clogit choice price price2 IN2 IN3 hosp_serv excess anc_copay dental optical P2 P3 naturo massage, cl(id) group(group)

foreach x in IN2 IN3 hosp_serv excess anc_copay dental optical P2 P3 naturo massage {
nlcom (wtp_`x': -12*(_b[`x']/(_b[price]+2*_b[price2]*mprice)))
} //this loop calculated WTP for MNL

local cont age sex university no_phi excell vgood good fair ltime phi_litALL

lclogit choice price price2 IN2 IN3 hosp_serv excess anc_copay dental optical P2 P3 naturo massage, group(group) id(id) nclasses(3) membership(`cont') seed(123456789)
display e(bic) //Baysian information criterion
lclogitml


local exp1 exp([share1]_b[age]*avg_age+[share1]_b[sex]*avg_sex+[share1]_b[university]*avg_university+[share1]_b[no_phi]*avg_no_phi+[share1]_b[excell]*avg_excell+[share1]_b[vgood]*avg_vgood+[share1]_b[good]*avg_good+[share1]_b[fair]*avg_fair+[share1]_b[ltime]*avg_ltime+[share1]_b[phi_litALL]*avg_phi_litALL+[share1]_b[_cons])
local exp2 exp([share2]_b[age]*avg_age+[share2]_b[sex]*avg_sex+[share2]_b[university]*avg_university+[share2]_b[no_phi]*avg_no_phi+[share2]_b[excell]*avg_excell+[share2]_b[vgood]*avg_vgood+[share2]_b[good]*avg_good+[share2]_b[fair]*avg_fair+[share2]_b[ltime]*avg_ltime+[share2]_b[phi_litALL]*avg_phi_litALL+[share2]_b[_cons])

*WTP at means
foreach x in IN2 IN3 hosp_serv excess anc_copay dental optical P2 P3 naturo massage {
nlcom (wtp_`x': -12*([choice1]_b[`x']*(`exp1'/(1+`exp1'+`exp2'))+[choice2]_b[`x']*(`exp2'/(1+`exp1'+`exp2'))+[choice3]_b[`x']*(exp(0)/(1+`exp1'+`exp2')))/(([choice1]_b[price]+2*mprice*[choice1]_b[price2])*(`exp1'/(1+`exp1'+`exp2'))+([choice2]_b[price]+2*mprice*[choice2]_b[price2])*(`exp2'/(1+`exp1'+`exp2'))+([choice3]_b[price]+2*mprice*[choice3]_b[price2])*(exp(0)/(1+`exp1'+`exp2'))))
} //this loop cacluates WTP for LCL

